@@ -1,6 +1,6 @@
 import sqlite3
 
-def create_schema(cursor, schema, table_name):
+def create_schema(conn, schema, table_name):
     symbolic_assignment = ", ".join([name + "=?" for name, row_type in schema])
     symbolic_values = "(" + ", ".join(["?"] * (1 + len(schema))) + ")"
 
@@ -9,6 +9,8 @@ def create_schema(cursor, schema, table_name):
     select_string = "SELECT * FROM %s WHERE id=?" % (table_name)
     #lines pickle, parents pickle
 
+    cursor = conn.cursor()
+
     schema_definition = ", \n".join([name + " " + row_type for name, row_type in schema])
 
     try:
@@ -20,20 +22,20 @@ def create_schema(cursor, schema, table_name):
     except sqlite3.OperationalError:
         pass
 
-    def insert_into_db(cursor, obj):
+    def insert_into_db(obj):
         cursor.execute(
             insert_string,
             obj
         )
         sqlite3.IntegrityError
-        cursor.commit()
+        conn.commit()
 
-    def update_in_db(cursor, obj):
+    def update_in_db(obj):
         cursor.execute(update_string,
             obj
         )
 
-    def get_obj_from_db(cursor, key):
+    def get_obj_from_db(key):
         cursor.execute(select_string, (key))
         data = cursor.fetchone()
         return data
